==> haskell-binary-conduit-1.3.1-61-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.3.1
id: binary-conduit-1.3.1-LkmunBC5ERcI0Iep8he9An
key: binary-conduit-1.3.1-LkmunBC5ERcI0Iep8he9An
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
author: Alexander Vershilov
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
abi: a20743569108f4a7f6709b4b5f9ebaa9
exposed: True
exposed-modules:
    Data.Conduit.Serialization.Binary
import-dirs: /usr/lib/ghc-8.6.5/site-local/binary-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/binary-conduit-1.3.1
hs-libraries: HSbinary-conduit-1.3.1-LkmunBC5ERcI0Iep8he9An
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    conduit-1.3.1.1-7uQvxkXSawE7t4T2ZzYFLO
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.3.1-63-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.3.1
id: binary-conduit-1.3.1-6dFWS0mbPix1UXa4Lcezyl
key: binary-conduit-1.3.1-6dFWS0mbPix1UXa4Lcezyl
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
author: Alexander Vershilov
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
abi: 17d7a329c9ce2b491bae989e8d8062a8
exposed: True
exposed-modules:
    Data.Conduit.Serialization.Binary
import-dirs: /usr/lib/ghc-8.6.5/site-local/binary-conduit-1.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/binary-conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/binary-conduit-1.3.1
hs-libraries: HSbinary-conduit-1.3.1-6dFWS0mbPix1UXa4Lcezyl
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    conduit-1.3.1.1-KLNDZz0JwjY8UxgeaedHmp
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
